==> fotoalbum-0.33.tar.bz2: fotoalbum-0.33/src/base/export.h <==
// -*- mode: c; mode: fold -*-
//
/*
 * Copyright (C) 2006-2008, 2010-2011  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef EXPORT_H
# define EXPORT_H

# include <string>
# include <vector>
# include <set>
# include <map>

# include "../shared/template.h"
# include "../shared/SimpleXMLTransfer.h"

class TreeItem;
class TreeView;
class TreePicBase;
class TreeGroupBase;

class PathAndPtr
{
public:
  
  PathAndPtr(std::string   mpath,
             TreePicBase*  mptr)
  {
    path = mpath;
    ptr  = mptr;
  }
  
  std::string  path;
  TreePicBase* ptr;
};

/**
 * 
 */
class ExpPicCache
{
public:  
  ExpPicCache(std::string strDir);
  ~ExpPicCache();
  
  /**
   * return cache path if this file is ok
   */
  std::string UpToDate(std::string strSrc, std::string strDstDir,
                       int nW, int nH, int nMode, int nQual);
  /**
   * Insert a file, returns cache name
   */
  std::string Insert(std::string strSrc, std::string strDstDir,
                     int nW, int nH, int nMode, int nQual);
private:
  std::string Name(std::string strSrc, int nW, int nH, int nMode, int nQual,
                   int nNr);
private:  
  std::string strDir;
  SimpleXMLTransfer* xState;
  int nNum;
  std::map<std::string, SimpleXMLTransfer*> mapC;
};


/**
 * This class does only handle some parts of an export.
 * Its main task is to create a list of paths (source and destination) and actions.
 *
 * It may also create a file with additional data.
 * 
 * It does not copy/shrink/or whatever by itself!
 */
class Export
{
public:
  
  enum eType      { eCopy=0, eShrink=1, eMetaOnly=2 };
  enum eStructure { eFlat=0, eFileSys=1, eView=2, eHTML=3 };
  
  eType        type;
  eStructure   structure;
  bool         fRecursive;
  bool         fThumbs;
  bool         fFollowLinks;
  bool         fDatafile;
  bool         fAddToJpeg;
  bool         fPrefix;
  bool         fHtml;
  unsigned int uThumbSize;
  std::string  destdir;
  
  TreeView*   data;
    
  bool fKwInherit;
  bool fKwMerge;
  bool fCommentOverwrite;
  
  void setOpts(SimpleXMLTransfer* exopts);
  
  void run(std::vector<TreeItem*> list);

  /**
   * If library to write exif/iptc is present:
   *   - add/overwrite "Exif.Photo.DateTimeOriginal"
   *   - add keywords to iptc data: "Iptc.Application2.Keywords"
   * Other data remains untouched.
   */
  int run_annotate();
  
  std::vector<std::string> copy;
  
  std::vector<std::string> shrink;
  std::vector<std::string> vThumbs;
  
  std::string error;
  
private:
  
  typedef std::set<std::string> SetOfStrings;
  
  std::vector<PathAndPtr> annotate;
    
  std::string getUniqueName(SetOfStrings&  namesInDir,
                            std::string    name);
  
  std::string GetHtmlName(int nNr);
  
  void WriteConvExif(std::ostream& out, std::string in);
  
  void HtmlLinks(std::string   link_up,
                 int           nNr,
                 bool          fNext,
                 std::string&  strLinkPrev,
                 std::string&  strLinkNext,
                 std::string&  strLinkUp,
                 std::string&  strURLNext);
  
  void picture(TreePicBase*       item,
               std::string        pathOfNames,
               SetOfStrings&      namesInDir,
               SimpleXMLTransfer* meta,
               int                nNr,
               std::string&       groupout,
               int&               nType,
               bool               fNext,
               std::string        strUp);
  
  void group(TreeGroupBase*     item,
             std::string        pathOfNames,
             SetOfStrings&      namesInDir,
             SimpleXMLTransfer* meta,
             int&               nNr,
             std::string&       groupout,
             int&               nType,
             bool               fNext,
             std::string        strUp,
             int&               nPrevGroup);
  
  void groupToFileHtml(std::string path,
                       std::string strLinkPrev,
                       std::string strLinkNext, 
                       std::string strLinkUp,
                       int         nPrevGroup,
                       int         nNextGroup,
                       std::string strText,
                       std::string strComment,
                       std::string strLinks,
                       std::string strThumbs,
                       std::string strKeywords);

  void PrepareTemplate(Template* templ);
  
  std::string GetLinLink(std::vector<TreePicBase*>*   listPics,   int nPicIdx,
                         std::vector<TreeGroupBase*>* listGroups, int nGroupIdx,
                         std::string strFallback);
private:
  Template* templ_pic;
  Template* templ_group;
  std::string templ_head;
  
  enum eTemplVar   { eTVHead=2, eTVButPrev=3, eTVButNext=4, eTVButUp=5, 
                     eTVDateTime=6, eTVFilename=7, eTVPath=8, eTVExif=9,
                     eTVComment=10, eTVKeywords=11, eTVTitle=12, eTVLinks=13, 
                     eTVThumbs=14, eTVFA_URL=15, eTVFA_Name=16, eTVFA_Version=17, 
                     eTVButPrevGroup=18,eTVButNextGroup=19,eTVURLNext=20};
  int nPicsInARow;
  ExpPicCache* pCache;
  
  unsigned int uShrinkMode;
  unsigned int uShrinkW, uShrinkH;
  unsigned int uShrinkQual;
  unsigned int uThumbQual;
};



#endif

==> fotoalbum-0.201.tar.bz2: fotoalbum-0.201/src/base/export.h <==
// -*- mode: c; mode: fold -*-
//
/*
 * Copyright (C) 2006-2008, 2010-2012  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef EXPORT_H
# define EXPORT_H

# include <string>
# include <vector>
# include <set>
# include <map>

# include "../shared/template.h"
# include "../shared/SimpleXMLTransfer.h"

class TreeView;
class ItPic;
class ItPicInGroup;
class ItGroup;

class PathAndPtr
{
public:
  
  PathAndPtr(std::string mpath,
             ItPic*      mptr,
             ItGroup*    mparent)
  {
    path   = mpath;
    ptr    = mptr;
    parent = mparent;
  }
  
  std::string path;
  ItPic*      ptr;
  ItGroup*    parent;
};

/**
 * 
 */
class ExpPicCache
{
public:  
  ExpPicCache(std::string strDir);
  ~ExpPicCache();
  
  /**
   * return cache path if this file is ok
   */
  std::string UpToDate(std::string strSrc, std::string strDstDir,
                       int nW, int nH, int nMode, int nQual);
  /**
   * Insert a file, returns cache name
   */
  std::string Insert(std::string strSrc, std::string strDstDir,
                     int nW, int nH, int nMode, int nQual);
private:
  std::string Name(std::string strSrc, int nW, int nH, int nMode, int nQual,
                   int nNr);
private:  
  std::string strDir;
  SimpleXMLTransfer* xState;
  int nNum;
  std::map<std::string, SimpleXMLTransfer*> mapC;
};


/**
 * This class does only handle some parts of an export.
 * Its main task is to create a list of paths (source and destination) and actions.
 *
 * It may also create a file with additional data.
 * 
 * It does not copy/shrink/or whatever by itself!
 */
class Export
{
public:
  
  enum eType      { eCopy=0, eShrink=1, eMetaOnly=2 };
  enum eStructure { eFlat=0, eFileSys=1, eView=2, eHTML=3 };
  
  eType        type;
  eStructure   structure;
  bool         fRecursive;
  bool         fThumbs;
  bool         fDatafile;
  bool         fAddToJpeg;
  bool         fPrefix;
  bool         fHtml;
  unsigned int uThumbSize;
  std::string  destdir;
  
  TreeView*   data;
    
  bool fKwInherit;
  bool fKwMerge;
  bool fCommentOverwrite;
  
  void setOpts(SimpleXMLTransfer* exopts);
  
  void run(std::vector<ItPicInGroup*> listPics, ItGroup* pPicParent, std::vector<ItGroup*> listGroups);
  void run(std::vector<ItPicInGroup*> listPics, ItGroup* pPicParent);
  void run(std::vector<ItGroup*> listGroups);
  
  /**
   * If library to write exif/iptc is present:
   *   - add/overwrite "Exif.Photo.DateTimeOriginal"
   *   - add keywords to iptc data: "Iptc.Application2.Keywords"
   * Other data remains untouched.
   */
  int run_annotate();
  
  std::vector<std::string> copy;
  
  std::vector<std::string> shrink;
  std::vector<std::string> vThumbs;
  
  std::string error;
  
private:
  
  typedef std::set<std::string> SetOfStrings;
  
  std::vector<PathAndPtr> annotate;
    
  std::string getUniqueName(SetOfStrings&  namesInDir,
                            std::string    name);
  
  std::string GetHtmlName(int nNr);
  
  void WriteConvExif(std::ostream& out, std::string in);
  
  void HtmlLinks(std::string   link_up,
                 int           nNr,
                 bool          fNext,
                 std::string&  strLinkPrev,
                 std::string&  strLinkNext,
                 std::string&  strLinkUp,
                 std::string&  strURLNext);
  
  void picture(ItPic*             item,
               std::string        pathOfNames,
               SetOfStrings&      namesInDir,
               int                nNr,
               std::string&       groupout,
               int&               nType,
               bool               fNext,
               std::string        strUp,
               ItGroup*           pParent);
  
  void group(ItGroup*           item,
             std::string        pathOfNames,
             SetOfStrings&      namesInDir,
             int&               nNr,
             std::string&       groupout,
             int&               nType,
             bool               fNext,
             std::string        strUp,
             int&               nPrevGroup);
  
  void groupToFileHtml(std::string path,
                       std::string strLinkPrev,
                       std::string strLinkNext, 
                       std::string strLinkUp,
                       int         nPrevGroup,
                       int         nNextGroup,
                       std::string strText,
                       std::string strComment,
                       std::string strLinks,
                       std::string strThumbs,
                       std::string strKeywords);

  void PrepareTemplate(Template* templ);
  
  std::string GetLinLink(std::vector<ItPic*>*   listPics,   int nPicIdx,
                         std::vector<ItGroup*>* listGroups, int nGroupIdx,
                         std::string strFallback);
  
  int RunPrep();
  
private:
  Template* templ_pic;
  Template* templ_group;
  std::string templ_head;
  
  enum eTemplVar   { eTVHead=2, eTVButPrev=3, eTVButNext=4, eTVButUp=5, 
                     eTVDateTime=6, eTVFilename=7, eTVPath=8, eTVExif=9,
                     eTVComment=10, eTVKeywords=11, eTVTitle=12, eTVLinks=13, 
                     eTVThumbs=14, eTVFA_URL=15, eTVFA_Name=16, eTVFA_Version=17, 
                     eTVButPrevGroup=18,eTVButNextGroup=19,eTVURLNext=20};
  int nPicsInARow;
  ExpPicCache* pCache;
  
  unsigned int uShrinkMode;
  unsigned int uShrinkW, uShrinkH;
  unsigned int uShrinkQual;
  unsigned int uThumbQual;
};



#endif
